# Instructions

#### This is our test project.
#### Please install this package
```
pip install functions-by-gregvalico==0.2.0
```
#### You can also install older packages
```
pip install functions-by-gregvalico==(VERSION HERE)
```